/*\file ParameterOutput.c
 *\brief: build output vectors for parameter outputs (like strain rate, stress, penalty active sets, etc ...)
 */

#include "./ParameterOutput.h"

void mexFunction( int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[]){

	/*input datasets: */
	Elements* elements=NULL;
	Nodes* nodes=NULL;
	Loads* loads=NULL;
	Materials* materials=NULL;
	DataSet* results=NULL;
	int      analysis_type;
	int      sub_analysis_type;
	
	/* output datasets: */
	Mat Kgg=NULL;
	Vec pg=NULL;

	/*Boot module: */
	MODULEBOOT();

	/*checks on arguments on the matlab side: */
	CheckNumMatlabArguments(nlhs,NLHS,nrhs,NRHS,__FUNCT__,&ParameterOutputUsage);

	/*Input datasets: */
	FetchMatlabData((DataSet**)&elements,ELEMENTS);
	FetchMatlabData((DataSet**)&nodes,NODES);
	FetchMatlabData((DataSet**)&loads,LOADS);
	FetchMatlabData((DataSet**)&materials,MATERIALS);
	FetchMatlabData(&results,RESULTS);
	
	/*parameters: */
	FetchMatlabData(&analysis_type,ANALYSIS);
	FetchMatlabData(&sub_analysis_type,SUBANALYSIS);

	/*!Generate internal degree of freedom numbers: */
	ParameterOutputx(results, elements,nodes,loads,materials,analysis_type,sub_analysis_type); 

	/*write output datasets: */
	WriteMatlabData(RESULTS,results,0,0,"DataSet",NULL); 
	
	/*Free ressources: */
	delete elements;
	delete nodes;
	delete loads;
	delete materials;
	delete results;

	/*end module: */
	MODULEEND();
}

void ParameterOutputUsage(void)
{
	_printf_(true,"\n");
	_printf_(true,"   usage: [Kgg,pg] = %s(eleemnts,nodes,loads,materials,params,analysis_type);\n",__FUNCT__);
	_printf_(true,"\n");
}
